##' @importFrom magrittr %>%
##' @export
magrittr::`%>%`

##' @importFrom RxODE RxODE
##' @export
RxODE::RxODE

##' @importFrom RxODE rxSolve
##' @export
RxODE::rxSolve


##' @importFrom RxODE rxClean
##' @export
RxODE::rxClean

##' @importFrom RxODE rxCat
##' @export
RxODE::rxCat

##' @importFrom nlme nlme
##' @export
nlme::nlme

##' @importFrom nlme ACF
##' @export
nlme::ACF

##' @importFrom nlme VarCorr
##' @export
nlme::VarCorr

##' @importFrom nlme getVarCov
##' @export
nlme::getVarCov


##' @importFrom nlme augPred
##' @export
nlme::augPred

##' @importFrom nlme fixef
##' @export
nlme::fixef

##' @importFrom nlme fixed.effects
##' @export
nlme::fixed.effects

##' @importFrom nlme ranef
##' @export
nlme::ranef

##' @importFrom nlme random.effects
##' @export
nlme::random.effects

##' @importFrom nlme nlmeControl
##' @export
nlme::nlmeControl


##' @importFrom RxODE eventTable
##' @export
RxODE::eventTable

##' @importFrom RxODE add.dosing
##' @export
RxODE::add.dosing

##' @importFrom RxODE add.sampling
##' @export
RxODE::add.sampling

##' @importFrom RxODE rxPermissive
##' @export
RxODE::rxPermissive

##' @importFrom nlme pdDiag
##' @export
nlme::pdDiag

##' @importFrom nlme pdSymm
##' @export
nlme::pdSymm

##' @importFrom nlme pdLogChol
##' @export
nlme::pdLogChol

##' @importFrom nlme pdIdent
##' @export
nlme::pdIdent

##' @importFrom nlme pdCompSymm
##' @export
nlme::pdCompSymm

##' @importFrom nlme pdBlocked
##' @export
nlme::pdBlocked

##' @importFrom nlme pdNatural
##' @export
nlme::pdNatural

##' @importFrom nlme pdConstruct
##' @export
nlme::pdConstruct

##' @importFrom nlme pdFactor
##' @export
nlme::pdFactor

##' @importFrom nlme pdMat
##' @export
nlme::pdMat

##' @importFrom nlme pdMatrix
##' @export
nlme::pdMatrix

##' @importFrom nlme reStruct
##' @export
nlme::reStruct

##' @importFrom nlme varWeights
##' @export
nlme::varWeights

##' @importFrom nlme varPower
##' @export
nlme::varPower

##' @importFrom nlme varFixed
##' @export
nlme::varFixed

##' @importFrom nlme varFunc
##' @export
nlme::varFunc

##' @importFrom nlme varExp
##' @export
nlme::varExp

##' @importFrom nlme varConstPower
##' @export
nlme::varConstPower

##' @importFrom nlme varIdent
##' @export
nlme::varIdent

##' @importFrom nlme varComb
##' @export
nlme::varComb

##' @importFrom nlme groupedData
##' @export
nlme::groupedData

##' @importFrom nlme getData
##' @export
nlme::getData
